==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/PICKLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PICKLIST_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PICKLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PICKLIST" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element name="PICKLISTDESC" type="{http://schemas.datastream.net/MP_fields}DESCRIPTION_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PICKLIST_Type", propOrder = {
    "picklist",
    "picklistdesc"
})
public class PICKLIST_Type {

    @XmlElement(name = "PICKLIST", required = true)
    protected String picklist;
    @XmlElement(name = "PICKLISTDESC")
    protected String picklistdesc;

    /**
     * Obtient la valeur de la propriété picklist.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPICKLIST() {
        return picklist;
    }

    /**
     * Définit la valeur de la propriété picklist.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPICKLIST(String value) {
        this.picklist = value;
    }

    /**
     * Obtient la valeur de la propriété picklistdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPICKLISTDESC() {
        return picklistdesc;
    }

    /**
     * Définit la valeur de la propriété picklistdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPICKLISTDESC(String value) {
        this.picklistdesc = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/PICKLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PICKLIST_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PICKLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PICKLIST" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *         &lt;element name="PICKLISTDESC" type="{http://schemas.datastream.net/MP_fields}DESCRIPTION_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PICKLIST_Type", propOrder = {
    "picklist",
    "picklistdesc"
})
public class PICKLIST_Type {

    @XmlElement(name = "PICKLIST", required = true)
    protected String picklist;
    @XmlElement(name = "PICKLISTDESC")
    protected String picklistdesc;

    /**
     * Gets the value of the picklist property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPICKLIST() {
        return picklist;
    }

    /**
     * Sets the value of the picklist property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPICKLIST(String value) {
        this.picklist = value;
    }

    /**
     * Gets the value of the picklistdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPICKLISTDESC() {
        return picklistdesc;
    }

    /**
     * Sets the value of the picklistdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPICKLISTDESC(String value) {
        this.picklistdesc = value;
    }

}
